<?php
namespace App\Http\Controllers;

use DateTime;
use DB;
use Auth;
use Session;
use Mail;

use App\Mail\NewUser;
// use App\Mail\NewComment;
// use App\Mail\CommentDone;
// use App\Mail\CommentUndone;
// use App\Mail\TaskDone;
// use App\Mail\TaskUndone;
// use App\Mail\TaskAcknowledged;
// use App\Mail\TaskUnacknowledged;
// use App\Mail\FileUpload;

use App\Models\Users;
use App\Models\Roles;
use App\Models\Clients;
use App\Models\Consultants;
use App\Models\Projects;
use App\Models\Standards;
use App\Models\Templates;

use Illuminate\Http\Request;

// use Illuminate\Support\Facades\Auth;
// use Illuminate\Support\Facades\Input;
// use App\Helpers\Contracts\CommentInterface;
// use Illuminate\Contracts\Routing\ResponseFactory;

class ClientsController extends Controller
{
    // protected $comment_inteface;

    // public function __construct(CommentInterface $comment_inteface){
    //     $this->comment_inteface = $comment_inteface;
    // }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request) {
    	$current_user_id = Auth::id();

        $current_user_role_id = Users::select(['role_id'])
            ->where('id', $current_user_id)
            ->pluck('role_id');

        if (empty($_GET["client_name"])) {
            // if ( $current_user_role_id[0] == 1 ) {
                $clients = DB::table('clients')
                    ->LeftJoin('consultants', 'clients.consultant_id', '=', 'consultants.id')
                    ->LeftJoin('projects', 'projects.client_id', '=', 'clients.id')
                    ->select('clients.*', 'consultants.id as consultant_id', 'consultants.primary_contact_firstname as consultant_firstname', 'consultants.primary_contact_lastname as consultant_lastname', 'projects.id as project_id', 'projects.name as project_name')
                    ->get();
            // }
        }
        elseif (!empty($_GET["client_name"])) {
            $client_name = $_GET["client_name"];
            $clients = DB::table('clients')
                ->where(function($query) use ($client_name){
                    $query->where('clients.organization_name', 'like', '%'.$client_name.'%');
                })
                ->LeftJoin('consultants', 'clients.consultant_id', '=', 'consultants.id')
                ->LeftJoin('projects', 'projects.client_id', '=', 'clients.id')
                ->select('clients.*', 'consultants.id as consultant_id', 'consultants.primary_contact_firstname as consultant_firstname', 'consultants.primary_contact_lastname as consultant_lastname', 'projects.id as project_id', 'projects.name as project_name')
                ->get();
        }
        
        return view('clients.index', compact('clients'));
    }


    /**
     * Create a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create() {
        $current_user_id = Auth::id();

        $current_user_role_id = Users::select(['role_id'])
            ->where('id', $current_user_id)
            ->pluck('role_id');

        // if ( $current_user_role_id[0] == 1 ) {
        //     $selected_admin = $current_user_id;
        // }
        // else {
        //     $selected_admin = "";
        // }

        $standards = Standards::select(['id','name'])
            ->pluck('name', 'id');

        $templates = Templates::select(['id','name'])
            ->pluck('name', 'id');

        $consultants = Consultants::select(['id','primary_contact_firstname'])
            ->pluck('primary_contact_firstname', 'id');

        return view('clients.create', compact('standards', 'templates', 'consultants'));
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
    	request()->validate([
            'organization_name' => 'required',
            'phone' => 'required',
            'employees' => 'required',
            'sites' => 'required',
            'website' => 'required',
            'street' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zip' => 'required',
            'primary_contact_firstname' => 'required',
            'primary_contact_lastname' => 'required',
            'email' => 'required|string|email|max:255|unique:users',
            'primary_contact_phone' => 'required',
            'client_admin_firstname' => 'required',
            'client_admin_lastname' => 'required',
            'client_admin_email' => 'required',
            'client_admin_phone' => 'required',
            'subscription_type' => 'required',
            'standard_id' => 'required',
            'template_id' => 'required',
            'consultant_id' => 'required',
            // 'files' => 'required',                
        ]);

        // $request = $request->all();

        // $admins_string = "";

        // for ($i=1; $i <= $request['admins_count']; $i++) {
        //     $current_admin = 'admin-'.$i;

        //     if ($request[$current_admin]) {
        //         if ($admins_string) {
        //             $admins_string .= ",".$request[$current_admin];
        //         }
        //         else {
        //             $admins_string .= $request[$current_admin];
        //         }
        //     }
        // }

        $client = Clients::create([
            'organization_name' => $request['organization_name'],
            'phone' => $request['phone'],
            'employees' => $request['employees'],
            'sites' => $request['sites'],
            'website' => $request['website'],
            'street' => $request['street'],
            'city' => $request['city'],
            'state' => $request['state'],
            'zip' => $request['zip'],
            'primary_contact_firstname' => $request['primary_contact_firstname'],
            'primary_contact_lastname' => $request['primary_contact_lastname'],
            'primary_contact_email' => $request['email'],
            'primary_contact_phone' => $request['primary_contact_phone'],
            'client_admin_firstname' => $request['client_admin_firstname'],
            'client_admin_lastname' => $request['client_admin_lastname'],
            'client_admin_email' => $request['client_admin_email'],
            'client_admin_phone' => $request['client_admin_phone'],
            'subscription_type' => $request['subscription_type'],
            'standard_id' => $request['standard_id'],            
            'template_id' => $request['template_id'],
            'consultant_id' => $request['consultant_id'],
            // 'files' => $request['files'],  
        ]);

        // $sendEmail = new TasksController;
        // $sendEmail->sendEmail($task->id, array(), "NewTask");

        $files = $request->file('files');
    	$file_names = "";
        $counter = 0;
        if (!empty($files)) {
            foreach ($files as $file) {
                $file_name = $file->getClientOriginalName();
                $destinationPath = public_path('/uploads/clients/'.$client->id);
                $file->move($destinationPath, $file_name);

                // $details = [
                //     'file_name' => $file_name,
                //     'file_path' => public_path('/uploads/clients/'.$client->id.'/'.$file_name)
                // ];
                // $sendEmail = new TasksController;
                // $sendEmail->sendEmail($client->id, $details, "FileUpload");
                
                $counter++;
                if ($counter==1) {
                    $file_names .= $file_name;
                }
                else {
                    $file_names .= ','.$file_name;
                }
            }
        }

    	Clients::where('id', $client->id)
    	    ->update(array(
                'files' => $file_names,
            ));
            
        function generateRandomString($length = 10) {
            $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
            $charactersLength = strlen($characters);
            $randomString = '';
            for ($i = 0; $i < $length; $i++) {
                $randomString .= $characters[rand(0, $charactersLength - 1)];
            }
            return $randomString;
        }

        $password = generateRandomString();

        Users::create([
            'email' => $request['email'],
            'password' => bcrypt($password),
            'role_id' => "2",
            'linked_user_id' => $client->id, 
        ]);

       
        $details["email"] = $request['email'];
        $details["password"] = $password;
        $details["link"] = url('/');

        \Mail::to($request['email'])->send(new NewUser($details));

        return redirect()->route('clients.index')->with('success', 'Client added successfully.');
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        $task = DB::table('tasks')
            ->LeftJoin('users', 'users.id', '=', 'tasks.user_id')
            ->LeftJoin('clients', 'clients.id', '=', 'tasks.client_id')
            ->where("tasks.id", $id)
            ->select('tasks.*', 'users.firstname as user_firstname', 'users.lastname as user_lastname', 'clients.name as client_name')
            ->get();

        $client = Clients::where("clients.id", $task[0]->client_id)
            ->select('clients.name')
            ->get();

        $user = Users::where("users.id", $task[0]->user_id)
            ->select('users.firstname', 'users.lastname')
            ->get();

        $comments = DB::table('comments')
            ->where('comments.parent_id', 0)
            ->where('comments.task_id', $task[0]->id)
            ->LeftJoin('users', 'users.id', '=', 'comments.user_id')
            ->orderBy('comments.created_at', 'desc')
            ->select('comments.*', 'users.firstname as user_firstname', 'users.lastname as user_lastname')
            ->get();

        // foreach ($comments as $comment) {
        //     $parent_id = $comment->id;
        //     $child_comments = DB::table('comments')
        //         ->where('comments.parent_id', $parent_id)
        //         ->where('comments.task_id', $task[0]->id)
        //         ->LeftJoin('users', 'users.id', '=', 'comments.user_id')
        //         ->orderBy('comments.created_at', 'asc')
        //         ->select('comments.*', 'users.firstname as user_firstname', 'users.lastname as user_lastname')
        //         ->get();
        //     $comment->child_comments = $child_comments;
        // }

        return view('tasks.show', compact('task', 'comments', 'client', 'user'));
    }


    /**
     * Edit the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {
        $current_user_id = Auth::id();

        $current_user_role_id = Users::select(['role_id'])
            ->where('id', $current_user_id)
            ->pluck('role_id');

        // if ( $current_user_role_id[0] == 1 ) {
        //     $selected_admin = $current_user_id;
        // }
        // else {
        //     $selected_admin = "";
        // }

        $client = DB::table('clients')
            ->where("clients.id", $id)
            ->select('clients.*')
            ->get();

        $standards = Standards::select(['id','name'])
            ->pluck('name', 'id');

        $templates = Templates::select(['id','name'])
            ->pluck('name', 'id');

        $consultants = Consultants::select(['id','primary_contact_firstname'])
            ->pluck('primary_contact_firstname', 'id');

        $change_password_url = url("users/2/".$client[0]->id."/change_password");

        return view('clients.edit', compact('client', 'standards', 'templates', 'consultants', 'change_password_url'));
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        request()->validate([
            'organization_name' => 'required',
            'phone' => 'required',
            'employees' => 'required',
            'sites' => 'required',
            'website' => 'required',
            'street' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zip' => 'required',
            'primary_contact_firstname' => 'required',
            'primary_contact_lastname' => 'required',
            'email' => 'required',
            'primary_contact_phone' => 'required',
            'client_admin_firstname' => 'required',
            'client_admin_lastname' => 'required',
            'client_admin_email' => 'required',
            'client_admin_phone' => 'required',
            'subscription_type' => 'required',
            'standard_id' => 'required',
            'template_id' => 'required',
            'consultant_id' => 'required',
            // 'files' => 'required',                
        ]);

        // $request = $request->all();

        // $admins_string = "";

        // for ($i=1; $i <= $request['admins_count']; $i++) {
        //     $current_admin = 'admin-'.$i;

        //     if ($request[$current_admin]) {
        //         if ($admins_string) {
        //             $admins_string .= ",".$request[$current_admin];
        //         }
        //         else {
        //             $admins_string .= $request[$current_admin];
        //         }
        //     }
        // }

        $client = Clients::where('id', $id)
            ->update([
            'organization_name' => $request['organization_name'],
            'phone' => $request['phone'],
            'employees' => $request['employees'],
            'sites' => $request['sites'],
            'website' => $request['website'],
            'street' => $request['street'],
            'city' => $request['city'],
            'state' => $request['state'],
            'zip' => $request['zip'],
            'primary_contact_firstname' => $request['primary_contact_firstname'],
            'primary_contact_lastname' => $request['primary_contact_lastname'],
            'primary_contact_email' => $request['email'],
            'primary_contact_phone' => $request['primary_contact_phone'],
            'client_admin_firstname' => $request['client_admin_firstname'],
            'client_admin_lastname' => $request['client_admin_lastname'],
            'client_admin_email' => $request['client_admin_email'],
            'client_admin_phone' => $request['client_admin_phone'],
            'subscription_type' => $request['subscription_type'],
            'standard_id' => $request['standard_id'],            
            'template_id' => $request['template_id'],
            'consultant_id' => $request['consultant_id'],
            // 'files' => $request['files'],  
        ]);

        // $sendEmail = new TasksController;
        // $sendEmail->sendEmail($task->id, array(), "NewTask");

        $old_files = Clients::where('id', $id)
            ->select('files')
            ->get();

        $files = $request->file('files');
    	$file_names = "";
    	$same_file_count = 0;
    	$counter = 0;
    	if (!empty($files)) {
            foreach ($files as $file) {
                $file_original_name = $file->getClientOriginalName();
                $file_name = $file_original_name;
                while ( strpos( $old_files[0]->files, $file_name ) !== false ) {
                    $same_file_count++;
                    $file_array=explode(".", $file_original_name);
                    $file_array_last_item = count($file_array)-1;
                    $file_array[$file_array_last_item] = "-".$same_file_count.".".$file_array[$file_array_last_item];
                    $file_name = implode("", $file_array);
                }

                $destinationPath = public_path('/uploads/clients/'.$id);
                $file->move($destinationPath, $file_name);

                // $details = [
                //     'file_name' => $file_name,
                //     'file_path' => public_path('/uploads/clients/'.$id.'/'.$file_name)
                // ];
                // $sendEmail = new TasksController;
                // $sendEmail->sendEmail($id, $details, "FileUpload");

                $counter++;
                if ($counter==1) {
                    $file_names .= $file_name;
                }
                else {
                    $file_names .= ','.$file_name;
                }
            }
    	}

        if ($old_files[0]->files) {
        	Clients::where('id', $id)
	    	    ->update(array(
	    	    	'files' => $old_files[0]->files . "," . $file_names,
	    	    ));
        }
        else {
        	Clients::where('id', $id)
	    	    ->update(array(
	    	    	'files' => $file_names,
	    	    ));
        }

        return redirect()->route('clients.index')->with('success', 'Client edited successfully.');
    }


    /**
     *
     * Task file upload
     *
    **/
    public function taskFileUpload(Request $request, $id) {
        request()->validate([
            'files'    => 'required',           
        ]);

        $old_files = Tasks::where('id', $id)
            ->select('files')
            ->get();

        $files = $request->file('files');
    	$file_names = "";
    	$same_file_count = 0;
    	$counter = 0;
    	if (!empty($files)) {
            foreach ($files as $file) {
                $file_original_name = $file->getClientOriginalName();
                $file_name = $file_original_name;
                while ( strpos( $old_files[0]->files, $file_name ) !== false ) {
                    $same_file_count++;
                    $file_array=explode(".", $file_original_name);
                    $file_array_last_item = count($file_array)-1;
                    $file_array[$file_array_last_item] = "-".$same_file_count.".".$file_array[$file_array_last_item];
                    $file_name = implode("", $file_array);
                }

                $destinationPath = public_path('/uploads/tasks/'.$id);
                $file->move($destinationPath, $file_name);

                $details = [
                    'file_name' => $file_name,
                    'file_path' => public_path('/uploads/tasks/'.$id.'/'.$file_name)
                ];
                $sendEmail = new TasksController;
                $sendEmail->sendEmail($id, $details, "FileUpload");
            
                $counter++;
                if ($counter==1) {
                    $file_names .= $file_name;
                }
                else {
                    $file_names .= ','.$file_name;
                }
            }
    	}

        if ($old_files[0]->files) {
        	Tasks::where('id', $id)
	    	    ->update(array(
	    	    	'files' => $old_files[0]->files . "," . $file_names,
	    	    ));
        }
        else {
        	Tasks::where('id', $id)
	    	    ->update(array(
	    	    	'files' => $file_names,
	    	    ));
        }

        return back()->with('success','File Upload successful');
    }


    /**
     *
     * client assign status change
     *
    **/
    public function assign(Request $request, $client_id) {
        $assign = DB::table('clients')
            ->where('id', $client_id)
            ->pluck('assign');

        if ($assign[0] == "yes") {
            DB::table('clients')
                ->where('id', $client_id)
                ->update(array(
                    'assign' => "no",
                ));

            // $sendEmail = new TasksController;
            // $sendEmail->sendEmail($task_id, array(), "TaskUndone");
        }
        else {
            DB::table('clients')
                ->where('id', $client_id)
                ->update(array(
                    'assign' => "yes",
                ));

            // $sendEmail = new TasksController;
            // $sendEmail->sendEmail($task_id, array(), "TaskDone");
        }

        return back()->with('success','Client assign status changed!');
    }

    public function get_consultants_names($consultants_string) {
        if ($consultants_string) {
            $consultants_array = explode(",", $consultants_string);
            $consultants_array_count = count($consultants_array);
            $consultants_names = "";
            for ($i=0; $i < $consultants_array_count; $i++) {            
                $consultant = Consultants::where("consultants.id", $consultants_array[$i])
                    ->select('consultants.primary_contact_firstname', 'consultants.primary_contact_lastname')
                    ->get();
                if (($i+1) == $consultants_array_count) {
                    $consultants_names .= $consultant[0]->primary_contact_firstname." ".$consultant[0]->primary_contact_firstname;
                }
                else {
                    $consultants_names .= $consultant[0]->primary_contact_lastname." ".$consultant[0]->primary_contact_lastname.", ";
                }
            }
            return $consultants_names;
        }
        return "";        
    }


    /**
     *
     * Task file acknowledge status change
     *
    **/
    // public function acknowledge(Request $request, $task_id) {
    //     $acknowledge = DB::table('tasks')
    //         ->where('id', $task_id)
    //         ->pluck('acknowledge');

    //     if ($acknowledge[0] == "yes") {
    //         DB::table('tasks')
    //             ->where('id', $task_id)
    //             ->update(array(
    //                 'acknowledge' => "no",
    //             ));

    //         $sendEmail = new TasksController;
    //         $sendEmail->sendEmail($task_id, array(), "TaskUnacknowledged");
    //     }
    //     else {
    //         DB::table('tasks')
    //             ->where('id', $task_id)
    //             ->update(array(
    //                 'acknowledge' => "yes",
    //                 'acknowledge_date' => DB::raw('NOW()'),
    //             ));

    //         $sendEmail = new TasksController;
    //         $sendEmail->sendEmail($task_id, array(), "TaskAcknowledged");
    //     }

    //     return back()->with('success','Task acknowledge status changed!');
    // }


    /**
     *
     * Task add comment
     *
    **/
    // public function add_comment(Request $request, $id) {
    //     request()->validate([
    //         'comment_text'    => 'required',
    //     ]);

    //     $request = $request->all();

    //     $current_user_id = Auth::id();

    //     Comments::create([
    //         'text' => $request['comment_text'],
    //         'parent_id' => $request['parent_id'],
    //         'task_id' => $id,
    //         'user_id' => $current_user_id,
    //     ]);

    //     $details = [
    //         'comment_text' => $request['comment_text']
    //     ];
    //     $sendEmail = new TasksController;
    //     $sendEmail->sendEmail($id, $details, "NewComment");

    //     return back()->with('success','Comment added!');
    // }


    /**
     *
     * Task close comment
     *
    **/
    // public function close_comment(Request $request, $id, $comment_id) {
    //     $comment = DB::table('comments')
    //         ->where('id', $comment_id)
    //         ->get();

    //     if ($comment[0]->status == "open") {
    //         DB::table('comments')
    //             ->where('id', $comment_id)
    //             ->update(array(
    //                 'status' => "closed",
    //             ));

    //         $details = [
    //             'comment_text' => strip_tags($comment[0]->text)
    //         ];
    //         $sendEmail = new TasksController;
    //         $sendEmail->sendEmail($comment[0]->task_id, $details, "CommentDone");
    //     }
    //     else {
    //         DB::table('comments')
    //             ->where('id', $comment_id)
    //             ->update(array(
    //                 'status' => "open",
    //             ));

    //         $details = [
    //             'comment_text' => strip_tags($comment[0]->text)
    //         ];
    //         $sendEmail = new TasksController;
    //         $sendEmail->sendEmail($comment[0]->task_id, $details, "CommentUndone");
    //     }

    //     return back()->with('success','Comment status changed!');
    // }


    /**
     *
     * Get task child comments
     *
    **/
    // public function get_child_comments($parent_id) {
    //     $child_comments = DB::table('comments')
    //         ->where('comments.parent_id', $parent_id)
    //         // ->where('comments.task_id', $task[0]->id)
    //         ->LeftJoin('users', 'users.id', '=', 'comments.user_id')
    //         ->orderBy('comments.created_at', 'asc')
    //         ->select('comments.*', 'users.firstname as user_firstname', 'users.lastname as user_lastname')
    //         ->get();

    //     $child_comments_html = '<div class="child-comments">';
    //     foreach($child_comments as $child_comment) {
    //     	$child_comments_html .= '<div class="comment" id="'.$child_comment->id.'">';
    //     	$child_comments_html .= '<div class="card"><div class="card-header"><i class="fas fa-user"></i>'.$child_comment->user_firstname.'</div><div class="card-body">'.$child_comment->text.'</div><div class="card-footer"><div class="row align-items-center"><div class="col-4"><button class="btn btn-primary btn-sm reply">Reply</button></div><div class="col-8 text-right">'.$child_comment->created_at.'<a href="'.route('tasks.close_comment', ['id'=>$child_comment->task_id, 'comment_id'=>$child_comment->id]).'">';
    //     	if ($child_comment->status == "open") {
    //     		$child_comments_html .= '<i class="fa fa-times-circle" title="Close comment"></i>';
    //     	}
    //     	else {
    //     		$child_comments_html .= '<i class="fa fa-check-circle" title="Open comment"></i>';
    //     	}
    //     	$child_comments_html .= '</a></div></div></div></div>';
	//         if (!empty($child_comments)) {
	//         	$get_child_comments = new TasksController;
    //             $child_comments_html .= $get_child_comments->get_child_comments($child_comment->id);
	//         	// echo get_child_comments($child_comment->id);
	//         }
    //     	$child_comments_html .= '</div>';
    //     }
    //     $child_comments_html .= '</div>';

    //     return $child_comments_html;
    // }


    /**
     *
     * Comment file upload
     *
    **/
    // public function commentFileUpload(Request $request, $id) {
    // 	$request->upload->move(public_path('/uploads/comments/'.$id), $request->file('upload')->getClientOriginalName());
    // 	echo json_encode(array('file_name' => $request->file('upload')->getClientOriginalName
    // 		()));
    // }


    /**
     *
     * Send email
     *
    **/
    // public function sendEmail($task_id, $details, $email_type) {
    //     $current_user_id = Auth::id();

    //     $task = Tasks::where("tasks.id", $task_id)
    //         ->select('tasks.*')
    //         ->get();

    //     $details["short_description"] = $task[0]->short_description;
    //     $details["importance"] = $task[0]->importance;
    //     $details["deadline"] = $task[0]->deadline;
    //     $details["description"] = $task[0]->description;
    //     $details["link"] = url('/');

    //     if ($task[0]->admins) {
    //         $admins_array = explode(",", $task[0]->admins);
    //     }
    //     else {
    //         $admins_array = array();
    //     }

    //     for ($j=0; $j < count($admins_array); $j++) {
    //         if ( $current_user_id != $admins_array[$j] ) {
    //             $admin = Users::where("users.id", $admins_array[$j])
    //                 ->select('users.*')
    //                 ->get();

    //             $details["firstname"] = $admin[0]->firstname;

    //             switch ($email_type) {
    //                 case 'NewTask':
    //                     \Mail::to($admin[0]->email)->send(new NewTask($details));
    //                     break;
    //                 case 'FileUpload':
    //                     \Mail::to($admin[0]->email)->send(new FileUpload($details));
    //                     break;
    //                 case 'NewComment':
    //                     \Mail::to($admin[0]->email)->send(new NewComment($details));
    //                     break;
    //                 case 'CommentDone':
    //                     \Mail::to($admin[0]->email)->send(new CommentDone($details));
    //                     break;
    //                 case 'CommentUndone':
    //                     \Mail::to($admin[0]->email)->send(new CommentUndone($details));
    //                     break;
    //                 case 'TaskDone':
    //                     \Mail::to($admin[0]->email)->send(new TaskDone($details));
    //                     break;
    //                 case 'TaskUndone':
    //                     \Mail::to($admin[0]->email)->send(new TaskUndone($details));
    //                     break;
    //                 case 'TaskAcknowledged':
    //                     \Mail::to($admin[0]->email)->send(new TaskAcknowledged($details));
    //                     break;
    //                 case 'TaskUnacknowledged':
    //                     \Mail::to($admin[0]->email)->send(new TaskUnacknowledged($details));
    //                     break;
                    
    //                 default:
    //                     break;
    //             }                
    //         }                
    //     }

    //     if ( $current_user_id != $task[0]->user_id ) {
    //         $user = Users::where("users.id", $task[0]->user_id)
    //             ->select('users.*')
    //             ->get();

    //         $details["firstname"] = $user[0]->firstname;

    //         switch ($email_type) {
    //             case 'NewTask':
    //                 \Mail::to($user[0]->email)->send(new NewTask($details));
    //                 break;
    //             case 'FileUpload':
    //                 \Mail::to($user[0]->email)->send(new FileUpload($details));
    //                 break;
    //             case 'NewComment':
    //                 \Mail::to($user[0]->email)->send(new NewComment($details));
    //                 break;
    //             case 'CommentDone':
    //                 \Mail::to($user[0]->email)->send(new CommentDone($details));
    //                 break;
    //             case 'CommentUndone':
    //                 \Mail::to($user[0]->email)->send(new CommentUndone($details));
    //                 break;
    //             case 'TaskDone':
    //                 \Mail::to($user[0]->email)->send(new TaskDone($details));
    //                 break;
    //             case 'TaskUndone':
    //                 \Mail::to($user[0]->email)->send(new TaskUndone($details));
    //                 break;
    //             case 'TaskAcknowledged':
    //                 \Mail::to($user[0]->email)->send(new TaskAcknowledged($details));
    //                 break;
    //             case 'TaskUnacknowledged':
    //                 \Mail::to($user[0]->email)->send(new TaskUnacknowledged($details));
    //                 break;
                
    //             default:
    //                 break;
    //         }
    //     }
    // }
}